@@ -2,9 +2,6 @@ import os
 import shutil
 import subprocess
 from pathlib import Path
-from pyfiglet import figlet_format
-from colorama import init
-from termcolor import cprint
 import click
 
 
@@ -24,7 +21,7 @@ def print_version(ctx, param, value):
     """Print current version"""
     if not value or ctx.resilient_parsing:
         return
-    click.echo("Version: 0.1.6")
+    click.echo("Version: 0.1.7")
     ctx.exit()
 
 
